alt-side-parking
=======================

Inspired by Jessica Garson's talk at Pycon https://us.pycon.org/2020/schedule/presentation/102/

Developing
-----------------------

.. -code-begin-

.. code-block:: bash

   >>> pip install -e '.[dev]'
   >>> tox -e lint && tox
   >>> git secret reveal
   >>> direnv allow
